<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Duplicate</name>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Dupliceren</translation>
    </message>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">Een object is gedupliceerd</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 objecten werden gedupliceerd</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation>
            <numerusform>Een object is gedupliceerd</numerusform>
            <numerusform>%n objecten werden gedupliceerd</numerusform>
        </translation>
    </message>
</context>
</TS>
